from django.http import HttpResponse, HttpResponseRedirect, HttpResponseForbidden
from django.contrib.auth.decorators import login_required
from django.utils.translation import ugettext as _

from jumbo.shortcuts import render_to_response, render_to_string
from jumbo.apps.accounts.forms import UserProfileForm
from jumbo.apps.accounts.models import UserProfile

@login_required
def redirect(request, default_url):
    try:
        userprofile = request.user.get_profile()
        if userprofile.default_url:
            return HttpResponseRedirect(userprofile.default_url)
        else:
            return HttpResponseRedirect(default_url)
    except:
        return HttpResponseRedirect(default_url)

@login_required
def profile(request, template_name='accounts/profile.html', forbidden_template_name='jumbo/forbidden.html'):
    user = request.user
    if not user.has_perm("accounts.can_view_userprofile"):
        return HttpResponseForbidden(render_to_string(forbidden_template_name))

    try:
        myprofile = request.user.get_profile()
    except:
        up = UserProfile(user=request.user)
        up.save()
        myprofile = request.user.get_profile()

    if request.method == 'POST':
        form = UserProfileForm(request.POST, instance=myprofile)
        if form.is_valid():
            form.save()
            message = _('Your Profile was changed successfully')
            request.user.message_set.create(message=message)
    else:
        form = UserProfileForm(instance=myprofile)

    return render_to_response(template_name, request=request, form=form, profile=myprofile)

