from django import forms
from django.utils.translation import ugettext_lazy as _
from django.core.mail import send_mail

from jumbo.forms import ModelForm, ModelSearchForm, DateWidget, DateTimeWidget
from jumbo.db.forms import AdminModelForm
from jumbo.apps.document.models import Document
import datetime

class DocumentSearchForm(ModelSearchForm):
    class Meta:
        model = Document
        fields = ('person', 'category', 'assigned_by', 'assigned_to', 'status', 'date_doc', 'number', 'reception_date', 'protocol_number', 'title', 'keywords', 'support')
        search_fields = {
            'organization__name':   'istartswith',
            'person__last_name':    'istartswith',
            'person__first_name':    'istartswith',
            'projects__name':       'icontains',
            'category':             'exact',
            'assigned_by':          'exact',
            'assigned_to':          'exact',
            'title':                'icontains',
            'support':              'exact',
            'keywords':             'icontains',
            'date_doc_gte':         'gte',
            'date_doc_lte':         'lte'
        }
        list_fields = (('organization__name', 'person__name'), ('assigned_by',))

    def __init__(self, *args, **kwargs):
        super(DocumentSearchForm, self).__init__(*args, **kwargs)
        self.fields['organization__name'] = forms.CharField(label=_("organization"), required=False)
        self.fields['person__last_name'] = forms.CharField(label=_("last name"), required=False)
        self.fields['person__first_name'] = forms.CharField(label=_("first name"), required=False)
        self.fields['projects__name'] = forms.CharField(label=_("project"), required=False)
        self.fields['date_doc_gte'] = forms.DateTimeField(label=_('date documents from'), widget=DateTimeWidget(), required=False)
        self.fields['date_doc_lte'] = forms.DateTimeField(label=_('date documents to'), widget=DateTimeWidget(), required=False)

class DocumentForm(ModelForm):
    class Meta:
        model = Document

    def __init__(self, *args, **kws):
        super(DocumentForm, self).__init__(*args, **kws)
        self.fields['title'].required=False