from django.conf import settings
from django.utils.translation import ugettext as _
from jumbo.core.urlresolvers import reverse
from jumbo.utils.functions import get_settings
from jumbo.middleware.thread_local import get_current_user
from jumbo.apps.document.models import Document

class DocumentList(object):
    model = Document
    list_display = ['status', 'category', 'get_notify_group', 'get_reception_date', 
                    'get_date_doc', 'number', 'protocol_number', 'support',
                    'get_link_title', 'get_download_file', 'get_del_icon']
    default_order_by= '-reception_date'

    def get_notify_group(self, result):
        return ",".join([ a.name for a in result.notify_group.all() ])
    get_notify_group.short_description = _("Notify Group")

    def get_reception_date(self, result):
        return result.reception_date.strftime("%d/%m/%y %H:%M")
    get_reception_date.short_description = _("Reception Date")

    def get_date_doc(self, result):
        return result.date_doc.strftime("%d/%m/%y %H:%M")
    get_date_doc.short_description = _("Document Date")

    def get_download_file(self, result):
        return "<a href='%(reverse_url)s' target='_blank'><img src='%(url)sjumbo/img/document.png' alt='%(window_title)s' /></a>" % {
            'reverse_url':reverse('document-document-download', result.id),
            'url':settings.MEDIA_URL,
            'window_title':_("Download File")
        }
    get_download_file.short_description = _("File")

    def get_link_title(self, result):
        if result.can_be_modified():
            return """<a href='%(reverse_url)s'">%(doc_name)s</a>""" % {
                                        'reverse_url':reverse('document-document-edit', result.id), 
                                        'doc_name':result.title}
        return result.title
    get_link_title.short_description = _("Title")


    def get_del_icon(self, result):
        if result.can_be_delete():
            return """<a href='%(reverse_url)s' onclick=\"jshowAddAnotherPopup(this, '%(window_title)s', 500, 500, 200, 200);return false;\">
                        <img src='%(url)sjumbo/img/del.png' title=\"%(window_title)s\" /></a>""" % {
                                            'reverse_url':reverse('document-document-delete', result.id), 
                                            'url':settings.MEDIA_URL, 
                                            'window_title':_("Delete Document")}

        return ""

    get_del_icon.short_description = _("Del")

