# -*- coding: utf-8 -*-

from south.db import db
from django.db import models
from jumbo.db.models import StatusField, HTMLField
from jumbo.apps.document.models import *

class Migration:
    depends_on = (
        ("project", "0001_initial"),
    )

    def forwards(self, orm):
        
        # Adding model 'Category'
        db.create_table('document_category', (
            ('status', StatusField()),
            ('note', models.TextField(null=True, verbose_name=_("Note"), blank=True)),
            ('code', models.CharField(max_length=15, unique=True, verbose_name=_('Code'), db_index=True)),
            ('last_modifier', models.ForeignKey(orm['auth.User'], db_index=True, related_name='%(app_label)s_%(class)s_last_modifier', null=True, verbose_name=_("last modifier"), blank=True)),
            ('creator', models.ForeignKey(orm['auth.User'], db_index=True, related_name="%(app_label)s_%(class)s_creator", null=True, verbose_name=_("creator"), blank=True)),
            ('ordering', models.IntegerField(default=0, verbose_name=_('ordering'))),
            ('email', models.EmailField(unique=True, verbose_name=_('Email'))),
            ('date_create', models.DateTimeField(verbose_name=_('date create'))),
            ('date_last_modify', models.DateTimeField(verbose_name=_('date last modify'))),
            ('id', models.AutoField(primary_key=True)),
            ('name', models.CharField(max_length=100, unique=True, verbose_name=_('Name'), db_index=True)),
        ))
        db.send_create_signal('document', ['Category'])
        
        # Adding model 'DocumentProject'
        db.create_table('document_documentproject', (
            ('project_ptr', models.OneToOneField(orm['project.Project'])),
        ))
        db.send_create_signal('document', ['DocumentProject'])
        
        # Adding model 'Document'
        db.create_table('document_document', (
            ('protocol_number', models.IntegerField(db_index=True, null=True, verbose_name=_("Protocol Number"), blank=True)),
            ('creator', models.ForeignKey(orm['auth.User'], db_index=True, related_name="%(app_label)s_%(class)s_creator", null=True, verbose_name=_("creator"), blank=True)),
            ('number', models.CharField(db_index=True, max_length=20, null=True, verbose_name=_("Document Number"), blank=True)),
            ('date_create', models.DateTimeField(verbose_name=_('date create'))),
            ('file', models.FileField(verbose_name=_("File PDF"))),
            ('keywords', models.CharField(db_index=True, max_length=200, null=True, verbose_name=_("Keywords"), blank=True)),
            ('id', models.AutoField(primary_key=True)),
            ('category', models.ForeignKey(orm.Category, verbose_name=_("Category"), db_index=True)),
            ('working', models.BooleanField(default=False, verbose_name=_("Working"), db_index=True)),
            ('title', models.CharField(max_length=100, verbose_name=_("Title"), db_index=True)),
            ('ordering', models.IntegerField(default=0, verbose_name=_('ordering'))),
            ('support', models.CharField(db_index=True, max_length=1, verbose_name=_("Support"))),
            ('assigned_by', models.ForeignKey(orm['auth.User'], related_name="documents_assigned_by_me", null=True, verbose_name=_("Assigned by"), blank=True)),
            ('note', models.TextField(null=True, verbose_name=_("Note"), blank=True)),
            ('status', models.CharField(db_index=True, max_length=2, verbose_name=_("Status"))),
            ('last_modifier', models.ForeignKey(orm['auth.User'], db_index=True, related_name='%(app_label)s_%(class)s_last_modifier', null=True, verbose_name=_("last modifier"), blank=True)),
            ('date_doc', models.DateTimeField(db_index=True, null=True, verbose_name=_("Document Date and Time"), blank=True)),
            ('pages', models.PositiveSmallIntegerField(max_length=3, null=True, verbose_name=_("Pages Number"), blank=True)),
            ('reception_date', models.DateTimeField(verbose_name=_("Reception Date"), db_index=True)),
            ('person', models.ForeignKey(orm['organization.Contact'], related_name="documents", null=True, verbose_name=_("Person"), blank=True)),
            ('assigned_to', models.ForeignKey(orm['auth.User'], related_name="documents_assigned_to_me", null=True, verbose_name=_("Assigned to"), blank=True)),
            ('organization', models.ForeignKey(orm['organization.Organization'], db_index=True, related_name="documents", null=True, verbose_name=_("Organization"), blank=True)),
            ('date_last_modify', models.DateTimeField(verbose_name=_('date last modify'))),
        ))
        db.send_create_signal('document', ['Document'])
        
        # Adding ManyToManyField 'Document.projects'
        db.create_table('document_document_projects', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('document', models.ForeignKey(Document, null=False)),
            ('documentproject', models.ForeignKey(DocumentProject, null=False))
        ))
        
        # Adding ManyToManyField 'DocumentProject.staff'
        db.create_table('document_documentproject_staff', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('documentproject', models.ForeignKey(DocumentProject, null=False)),
            ('user', models.ForeignKey(User, null=False))
        ))
        
        # Adding ManyToManyField 'DocumentProject.managers'
        db.create_table('document_documentproject_managers', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('documentproject', models.ForeignKey(DocumentProject, null=False)),
            ('user', models.ForeignKey(User, null=False))
        ))
        
    
    
    def backwards(self, orm):
        
        # Deleting model 'Category'
        db.delete_table('document_category')
        
        # Deleting model 'DocumentProject'
        db.delete_table('document_documentproject')
        
        # Deleting model 'Document'
        db.delete_table('document_document')
        
        # Dropping ManyToManyField 'Document.projects'
        db.delete_table('document_document_projects')
        
        # Dropping ManyToManyField 'DocumentProject.staff'
        db.delete_table('document_documentproject_staff')
        
        # Dropping ManyToManyField 'DocumentProject.managers'
        db.delete_table('document_documentproject_managers')
        
    
    
    models = {
        'auth.user': {
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'document.category': {
            'code': ('models.CharField', [], {'max_length': '15', 'unique': 'True', 'verbose_name': "_('Code')", 'db_index': 'True'}),
            'creator': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': '"%(app_label)s_%(class)s_creator"', 'null': 'True', 'verbose_name': '_("creator")', 'blank': 'True'}),
            'date_create': ('models.DateTimeField', [], {'verbose_name': "_('date create')"}),
            'date_last_modify': ('models.DateTimeField', [], {'verbose_name': "_('date last modify')"}),
            'email': ('models.EmailField', [], {'unique': 'True', 'verbose_name': "_('Email')"}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'last_modifier': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': "'%(app_label)s_%(class)s_last_modifier'", 'null': 'True', 'verbose_name': '_("last modifier")', 'blank': 'True'}),
            'name': ('models.CharField', [], {'max_length': '100', 'unique': 'True', 'verbose_name': "_('Name')", 'db_index': 'True'}),
            'note': ('models.TextField', [], {'null': 'True', 'verbose_name': '_("Note")', 'blank': 'True'}),
            'ordering': ('models.IntegerField', [], {'default': '0', 'verbose_name': "_('ordering')"}),
            'status': ('StatusField', [], {})
        },
        'project.project': {
            'Meta': {'ordering': "['name']", 'permissions': '(("can_view_projects","Can view projects"),("list_all_projects","Can list all projects"),)'},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'organization.contact': {
            'Meta': {'permissions': '(("can_view_contacts","Can view contacts"),)'},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'organization.organization': {
            'Meta': {'unique_together': '(("vat_number","ssn",),)', 'permissions': '(("can_view_organizations","Can view organizations"),)'},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'document.documentproject': {
            'Meta': {'ordering': "['name']", '_bases': ['jumbo.apps.project.models.Project'], 'permissions': '(("can_view_document_projects","Can view document projects"),("list_all_document_projects","Can list all document projects"),)'},
            'managers': ('models.ManyToManyField', ['User'], {'related_name': "'managed_documentprojects'", 'verbose_name': '_("Managers")', 'db_index': 'True'}),
            'project_ptr': ('models.OneToOneField', ["orm['project.Project']"], {}),
            'staff': ('models.ManyToManyField', ['User'], {'related_name': "'assigned_documentprojects'", 'verbose_name': '_("Staff")', 'db_index': 'True'})
        },
        'document.document': {
            'Meta': {'permissions': '(("list_all_documents","Can list all documents"),("list_own_documents","Can list own documents"),("modify_all_documents","Can modify all documents"),("modify_own_documents","Can modify only own documents"),("delete_own_documents","Can delete only own documents"),)'},
            'assigned_by': ('models.ForeignKey', ['User'], {'related_name': '"documents_assigned_by_me"', 'null': 'True', 'verbose_name': '_("Assigned by")', 'blank': 'True'}),
            'assigned_to': ('models.ForeignKey', ['User'], {'related_name': '"documents_assigned_to_me"', 'null': 'True', 'verbose_name': '_("Assigned to")', 'blank': 'True'}),
            'category': ('models.ForeignKey', ['Category'], {'verbose_name': '_("Category")', 'db_index': 'True'}),
            'creator': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': '"%(app_label)s_%(class)s_creator"', 'null': 'True', 'verbose_name': '_("creator")', 'blank': 'True'}),
            'date_create': ('models.DateTimeField', [], {'verbose_name': "_('date create')"}),
            'date_doc': ('models.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'verbose_name': '_("Document Date and Time")', 'blank': 'True'}),
            'date_last_modify': ('models.DateTimeField', [], {'verbose_name': "_('date last modify')"}),
            'file': ('models.FileField', [], {'verbose_name': '_("File PDF")'}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('models.CharField', [], {'db_index': 'True', 'max_length': '200', 'null': 'True', 'verbose_name': '_("Keywords")', 'blank': 'True'}),
            'last_modifier': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': "'%(app_label)s_%(class)s_last_modifier'", 'null': 'True', 'verbose_name': '_("last modifier")', 'blank': 'True'}),
            'note': ('models.TextField', [], {'null': 'True', 'verbose_name': '_("Note")', 'blank': 'True'}),
            'number': ('models.CharField', [], {'db_index': 'True', 'max_length': '20', 'null': 'True', 'verbose_name': '_("Document Number")', 'blank': 'True'}),
            'ordering': ('models.IntegerField', [], {'default': '0', 'verbose_name': "_('ordering')"}),
            'organization': ('models.ForeignKey', ['Organization'], {'db_index': 'True', 'related_name': '"documents"', 'null': 'True', 'verbose_name': '_("Organization")', 'blank': 'True'}),
            'pages': ('models.PositiveSmallIntegerField', [], {'max_length': '3', 'null': 'True', 'verbose_name': '_("Pages Number")', 'blank': 'True'}),
            'person': ('models.ForeignKey', ['Contact'], {'related_name': '"documents"', 'null': 'True', 'verbose_name': '_("Person")', 'blank': 'True'}),
            'projects': ('models.ManyToManyField', ['DocumentProject'], {'db_index': 'True', 'related_name': '"documents"', 'null': 'True', 'verbose_name': '_("Projects")', 'blank': 'True'}),
            'protocol_number': ('models.IntegerField', [], {'db_index': 'True', 'null': 'True', 'verbose_name': '_("Protocol Number")', 'blank': 'True'}),
            'reception_date': ('models.DateTimeField', [], {'verbose_name': '_("Reception Date")', 'db_index': 'True'}),
            'status': ('models.CharField', [], {'db_index': 'True', 'max_length': '2', 'verbose_name': '_("Status")'}),
            'support': ('models.CharField', [], {'db_index': 'True', 'max_length': '1', 'verbose_name': '_("Support")'}),
            'title': ('models.CharField', [], {'max_length': '100', 'verbose_name': '_("Title")', 'db_index': 'True'}),
            'working': ('models.BooleanField', [], {'default': 'False', 'verbose_name': '_("Working")', 'db_index': 'True'})
        }
    }
    
    complete_apps = ['document']
