# -*- coding: utf-8 -*-

from south.db import db
from django.db import models
from jumbo.db.models import StatusField, HTMLField
from jumbo.apps.l10n.models import *

class Migration:
    
    def forwards(self, orm):
        
        # Adding model 'AdministrativeArea'
        db.create_table('l10n_administrativearea', (
            ('active', models.BooleanField(default=True, verbose_name=_('Area is active'))),
            ('country', models.ForeignKey(orm.Country, related_name='administrative_areas')),
            ('abbrev', models.CharField(verbose_name=_('Postal Abbreviation'), max_length=3, null=True, blank=True)),
            ('id', models.AutoField(primary_key=True)),
            ('name', models.CharField(max_length=60, verbose_name=_('Admin Area name'), db_index=True)),
        ))
        db.send_create_signal('l10n', ['AdministrativeArea'])
        
        # Adding model 'Country'
        db.create_table('l10n_country', (
            ('name', models.CharField(max_length=128, verbose_name=_('Official name (CAPS)'), db_index=True)),
            ('admin_area', models.CharField(max_length=2, blank=True, null=True, verbose_name=_('Administrative Area'), db_index=True)),
            ('printable_name', models.CharField(max_length=128, verbose_name=_('Country name'), db_index=True)),
            ('continent', models.CharField(max_length=2, verbose_name=_('Continent'))),
            ('numcode', models.PositiveSmallIntegerField(null=True, verbose_name=_('ISO numeric'), blank=True)),
            ('active', models.BooleanField(default=True, verbose_name=_('Country is active'))),
            ('iso2_code', models.CharField(unique=True, max_length=2, verbose_name=_('ISO alpha-2'), db_index=True)),
            ('iso3_code', models.CharField(unique=True, max_length=3, verbose_name=_('ISO alpha-3'))),
            ('id', models.AutoField(primary_key=True)),
        ))
        db.send_create_signal('l10n', ['Country'])
        
    
    
    def backwards(self, orm):
        
        # Deleting model 'AdministrativeArea'
        db.delete_table('l10n_administrativearea')
        
        # Deleting model 'Country'
        db.delete_table('l10n_country')
        
    
    
    models = {
        'l10n.administrativearea': {
            'Meta': {'ordering': "('name',)"},
            'abbrev': ('models.CharField', [], {'verbose_name': "_('Postal Abbreviation')", 'max_length': '3', 'null': 'True', 'blank': 'True'}),
            'active': ('models.BooleanField', [], {'default': 'True', 'verbose_name': "_('Area is active')"}),
            'country': ('models.ForeignKey', ['Country'], {'related_name': "'administrative_areas'"}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'name': ('models.CharField', [], {'max_length': '60', 'verbose_name': "_('Admin Area name')", 'db_index': 'True'})
        },
        'l10n.country': {
            'Meta': {'ordering': "('iso2_code','name',)"},
            'active': ('models.BooleanField', [], {'default': 'True', 'verbose_name': "_('Country is active')"}),
            'admin_area': ('models.CharField', [], {'max_length': '2', 'blank': 'True', 'null': 'True', 'verbose_name': "_('Administrative Area')", 'db_index': 'True'}),
            'continent': ('models.CharField', [], {'max_length': '2', 'verbose_name': "_('Continent')"}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'iso2_code': ('models.CharField', [], {'unique': 'True', 'max_length': '2', 'verbose_name': "_('ISO alpha-2')", 'db_index': 'True'}),
            'iso3_code': ('models.CharField', [], {'unique': 'True', 'max_length': '3', 'verbose_name': "_('ISO alpha-3')"}),
            'name': ('models.CharField', [], {'max_length': '128', 'verbose_name': "_('Official name (CAPS)')", 'db_index': 'True'}),
            'numcode': ('models.PositiveSmallIntegerField', [], {'null': 'True', 'verbose_name': "_('ISO numeric')", 'blank': 'True'}),
            'printable_name': ('models.CharField', [], {'max_length': '128', 'verbose_name': "_('Country name')", 'db_index': 'True'})
        }
    }
    
    complete_apps = ['l10n']
