import re

from django.contrib import admin
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponseRedirect
from django.conf import settings
from django.db import transaction
from django.core.mail import EmailMessage
from django.utils.encoding import force_unicode

from jumbo.db.forms import AdminModelForm, OrderedModelAdmin
from newsletter.models import NewsLetter, Post, Subscriber

admin.site.register(Subscriber)

class PostAdminForm(AdminModelForm):
    class Meta:
        model = Post
class PostInline(admin.TabularInline):
    model = Post
    form = PostAdminForm
    fields = ('status','title','text',)
    ordering=('-status',)

class NewsLetterAdminForm(AdminModelForm):
    class Meta:
        model = NewsLetter
class NewsLetterAdmin(admin.ModelAdmin):
    form = NewsLetterAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_display = ('get_status_display', 'date_create', 'date_last_modify', 'name',)
    list_display_links = ("name",)
    list_per_page = 30
    fieldsets = (
        (_('logs admin'), {'fields': ('date_create','date_last_modify',), 'classes': ('collapse',)}),
        (None, {"fields":("status", 'name', 'description',),}),
    )
    ordering = ("name",)
    inlines = (PostInline,)
    #filter_horizontal = ('subscribers',)
admin.site.register(NewsLetter, NewsLetterAdmin)


class PostAdminForm(AdminModelForm):
    class Meta:
        model = Post
class PostAdmin(admin.ModelAdmin):
    class Media:
        css = {
            'all': ('%sadmin/css/widgets.css' % settings.ADMIN_MEDIA_PREFIX,),
        }

    form = PostAdminForm
    search_fields = ("status", "newsletter","title")
    date_hierarchy = "date_create"
    list_display = ('get_status_display', 'date_create', 'creator', 'date_last_modify', 'last_modifier', 'newsletter', 'title')
    list_display_links = ("title",)
    list_per_page = 30
    fieldsets = (
        (_('logs admin'), {'fields': ('date_create','date_last_modify',), 'classes': ('collapse',)}),
        (None, {"fields":("status", 'newsletter', 'title', 'text',),}),
    )
    ordering = ("status","newsletter","title")
    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        return patterns('',
                url(r'(?P<id>\d+)/send/$', self.admin_site.admin_view(self.send), name='newsletter-send'),
            ) + super(PostAdmin, self).get_urls()
    def send(self, request, id):
        post = Post.objects.get(pk=id)
        subscribers = post.newsletter.subscribers.all()
        emails = [ contact.email for contact in subscribers ]
        from_email = getattr(settings, 'DEFAULT_FROM_EMAIL', 'shop@hts.it')

        email = EmailMessage(
            subject=_('HTS Newsletter'),
            body=post.text,
            from_email=from_email,
            to=[],
            bcc=emails,
        )
        email.send(
            fail_silently=False,
        )
        post.status = 2
        post.save()

        self.message_user(request, _('The NewsLetter <%(name)s> was sent successfully.') % {'name': force_unicode(post.title)})

        return HttpResponseRedirect('../../')

admin.site.register(Post, PostAdmin)

