# -*- coding: utf-8 -*-

from south.db import db
from django.db import models
from jumbo.db.models import StatusField, HTMLField
from jumbo.apps.mailinglist.models import *

class Migration:
    
    def forwards(self, orm):
        
        # Adding model 'Post'
        db.create_table('mailinglist_post', (
            ('status', models.IntegerField(default=1, db_index=True, verbose_name=_('Status'))),
            ('sent_date', models.DateTimeField(verbose_name=_('Sent Date'), db_index=True)),
            ('last_modifier', models.ForeignKey(orm['auth.User'], db_index=True, related_name='%(app_label)s_%(class)s_last_modifier', null=True, verbose_name=_("last modifier"), blank=True)),
            ('creator', models.ForeignKey(orm['auth.User'], db_index=True, related_name="%(app_label)s_%(class)s_creator", null=True, verbose_name=_("creator"), blank=True)),
            ('text', HTMLField(verbose_name=_('Body'))),
            ('title', models.CharField(max_length=100, verbose_name=_('Title'), db_index=True)),
            ('date_create', models.DateTimeField(verbose_name=_('date create'))),
            ('newsletter', models.ForeignKey(orm.NewsLetter, related_name='posts', verbose_name=_('Newsletter'), db_index=True)),
            ('date_last_modify', models.DateTimeField(verbose_name=_('date last modify'))),
            ('id', models.AutoField(primary_key=True)),
        ))
        db.send_create_signal('mailinglist', ['Post'])
        
        # Adding model 'Subscriber'
        db.create_table('mailinglist_subscriber', (
            ('status', StatusField()),
            ('last_modifier', models.ForeignKey(orm['auth.User'], db_index=True, related_name='%(app_label)s_%(class)s_last_modifier', null=True, verbose_name=_("last modifier"), blank=True)),
            ('creator', models.ForeignKey(orm['auth.User'], db_index=True, related_name="%(app_label)s_%(class)s_creator", null=True, verbose_name=_("creator"), blank=True)),
            ('email', models.EmailField(null=True, verbose_name=_('Email'), blank=True)),
            ('date_create', models.DateTimeField(verbose_name=_('date create'))),
            ('contact', models.ForeignKey(orm['organization.Contact'], db_index=True, related_name='subscribers', null=True, verbose_name=_('Subscriber'), blank=True)),
            ('organization', models.ForeignKey(orm['organization.Organization'], db_index=True, related_name='subscribers', null=True, verbose_name=_('Subscriber'), blank=True)),
            ('date_last_modify', models.DateTimeField(verbose_name=_('date last modify'))),
            ('id', models.AutoField(primary_key=True)),
        ))
        db.send_create_signal('mailinglist', ['Subscriber'])
        
        # Adding model 'NewsLetter'
        db.create_table('mailinglist_newsletter', (
            ('status', StatusField()),
            ('last_modifier', models.ForeignKey(orm['auth.User'], db_index=True, related_name='%(app_label)s_%(class)s_last_modifier', null=True, verbose_name=_("last modifier"), blank=True)),
            ('creator', models.ForeignKey(orm['auth.User'], db_index=True, related_name="%(app_label)s_%(class)s_creator", null=True, verbose_name=_("creator"), blank=True)),
            ('description', models.TextField(null=True, verbose_name=_('Description'), blank=True)),
            ('date_create', models.DateTimeField(verbose_name=_('date create'))),
            ('date_last_modify', models.DateTimeField(verbose_name=_('date last modify'))),
            ('id', models.AutoField(primary_key=True)),
            ('name', models.CharField(max_length=255, unique=True, verbose_name=_('Name'), db_index=True)),
        ))
        db.send_create_signal('mailinglist', ['NewsLetter'])
        
        # Adding ManyToManyField 'Subscriber.newsletters'
        db.create_table('mailinglist_subscriber_newsletters', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('subscriber', models.ForeignKey(Subscriber, null=False)),
            ('newsletter', models.ForeignKey(NewsLetter, null=False))
        ))
        
    
    
    def backwards(self, orm):
        
        # Deleting model 'Post'
        db.delete_table('mailinglist_post')
        
        # Deleting model 'Subscriber'
        db.delete_table('mailinglist_subscriber')
        
        # Deleting model 'NewsLetter'
        db.delete_table('mailinglist_newsletter')
        
        # Dropping ManyToManyField 'Subscriber.newsletters'
        db.delete_table('mailinglist_subscriber_newsletters')
        
    
    
    models = {
        'auth.user': {
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'organization.contact': {
            'Meta': {'permissions': '(("can_view_contacts","Can view contacts"),)'},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'organization.organization': {
            'Meta': {'unique_together': '(("vat_number","ssn",),)', 'permissions': '(("can_view_organizations","Can view organizations"),)'},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'mailinglist.post': {
            'creator': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': '"%(app_label)s_%(class)s_creator"', 'null': 'True', 'verbose_name': '_("creator")', 'blank': 'True'}),
            'date_create': ('models.DateTimeField', [], {'verbose_name': "_('date create')"}),
            'date_last_modify': ('models.DateTimeField', [], {'verbose_name': "_('date last modify')"}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'last_modifier': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': "'%(app_label)s_%(class)s_last_modifier'", 'null': 'True', 'verbose_name': '_("last modifier")', 'blank': 'True'}),
            'newsletter': ('models.ForeignKey', ['NewsLetter'], {'related_name': "'posts'", 'verbose_name': "_('Newsletter')", 'db_index': 'True'}),
            'sent_date': ('models.DateTimeField', [], {'verbose_name': "_('Sent Date')", 'db_index': 'True'}),
            'status': ('models.IntegerField', [], {'default': '1', 'db_index': 'True', 'verbose_name': "_('Status')"}),
            'text': ('HTMLField', [], {'verbose_name': "_('Body')"}),
            'title': ('models.CharField', [], {'max_length': '100', 'verbose_name': "_('Title')", 'db_index': 'True'})
        },
        'mailinglist.subscriber': {
            'contact': ('models.ForeignKey', ['Contact'], {'db_index': 'True', 'related_name': "'subscribers'", 'null': 'True', 'verbose_name': "_('Subscriber')", 'blank': 'True'}),
            'creator': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': '"%(app_label)s_%(class)s_creator"', 'null': 'True', 'verbose_name': '_("creator")', 'blank': 'True'}),
            'date_create': ('models.DateTimeField', [], {'verbose_name': "_('date create')"}),
            'date_last_modify': ('models.DateTimeField', [], {'verbose_name': "_('date last modify')"}),
            'email': ('models.EmailField', [], {'null': 'True', 'verbose_name': "_('Email')", 'blank': 'True'}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'last_modifier': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': "'%(app_label)s_%(class)s_last_modifier'", 'null': 'True', 'verbose_name': '_("last modifier")', 'blank': 'True'}),
            'newsletters': ('models.ManyToManyField', ['"NewsLetter"'], {'related_name': "'subscribers'", 'verbose_name': "_('Newsletters')", 'db_index': 'True'}),
            'organization': ('models.ForeignKey', ['Organization'], {'db_index': 'True', 'related_name': "'subscribers'", 'null': 'True', 'verbose_name': "_('Subscriber')", 'blank': 'True'}),
            'status': ('StatusField', [], {})
        },
        'mailinglist.newsletter': {
            'creator': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': '"%(app_label)s_%(class)s_creator"', 'null': 'True', 'verbose_name': '_("creator")', 'blank': 'True'}),
            'date_create': ('models.DateTimeField', [], {'verbose_name': "_('date create')"}),
            'date_last_modify': ('models.DateTimeField', [], {'verbose_name': "_('date last modify')"}),
            'description': ('models.TextField', [], {'null': 'True', 'verbose_name': "_('Description')", 'blank': 'True'}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'last_modifier': ('models.ForeignKey', ['User'], {'db_index': 'True', 'related_name': "'%(app_label)s_%(class)s_last_modifier'", 'null': 'True', 'verbose_name': '_("last modifier")', 'blank': 'True'}),
            'name': ('models.CharField', [], {'max_length': '255', 'unique': 'True', 'verbose_name': "_('Name')", 'db_index': 'True'}),
            'status': ('StatusField', [], {})
        }
    }
    
    complete_apps = ['mailinglist']
