# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jumbo.db.models import DateModel, StatusModel, UserModel, HTMLField

from organization.models import Contact, Organization

class Subscriber(UserModel, DateModel, StatusModel):
    contact = models.ForeignKey(
        Contact,
        related_name = 'subscribers',
        blank = True, null = True,
        db_index=True,
        verbose_name=_('Subscriber'),
    )
    organization = models.ForeignKey(
        Organization,
        related_name = 'subscribers',
        blank = True, null = True,
        db_index=True,
        verbose_name=_('Subscriber'),
    )
    newsletters = models.ManyToManyField(
        "NewsLetter",
        related_name = 'subscribers',
        db_index = True,
        verbose_name = _('Newsletters'),
    )
    email = models.EmailField(
        blank = True, null = True,
        verbose_name = _('Email')
    )

    class Meta:
        verbose_name = _("Subscriber")
        verbose_name_plural = _("Subscribers")

    def __unicode__(self):
        if self.contact:
            return self.contact.email
        elif self.organization:
            return self.organization.email
        else:
            return self.email

class NewsLetter(UserModel, DateModel, StatusModel):
    ## Campi
    name = models.CharField (
        unique=True,
        max_length=255,
        db_index=True,
        verbose_name=_('Name'),
    )
    description = models.TextField (
        blank=True, null=True,
        verbose_name=_('Description'),
    )

    class Meta:
        verbose_name = _("Newsletter")
        verbose_name_plural = _("Newsletter")

    def __unicode__(self):
        return self.name

NEWSLETTER_POST_STATUS = (
    (1, _('Draft')),
    (2, _('Sent')),
)

class Post(UserModel, DateModel):
    status = models.IntegerField(
        default=1,
        choices=NEWSLETTER_POST_STATUS,
        db_index=True,
        verbose_name=_('Status'),
    )
    newsletter = models.ForeignKey(
        NewsLetter,
        related_name='posts',
        db_index=True,
        verbose_name=_('Newsletter'),
    )
    sent_date = models.DateTimeField(
        db_index=True,
        verbose_name=_('Sent Date'),
    )
    title = models.CharField(
        max_length=100,
        db_index=True,
        verbose_name=_('Title'),
    )
    text = HTMLField(
        verbose_name=_('Body'),
    )

    class Meta:
        verbose_name = _("Newsletter article")
        verbose_name_plural = _("Newsletter articles")

    def __unicode__(self):
        return u'%(newsletter)s - %(title)s' % {'title': self.title, 'newsletter': self.newsletter}

