# -*- coding: utf-8 -*-

from datetime import datetime

from django.db import models
from django.contrib.auth.models import User, Group, Permission
from django.utils.translation import ugettext_lazy as _
from django.conf import settings as ls

from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from organization.models import Organization, Contact

############################
# PROGETTO                 #
############################
PSTATUS_CODES = (
    (1, 'Open'),
    (0, 'Closed'),
)

class Project(DateModel, UserModel):
    status = models.IntegerField (
        default = '1',
        choices = PSTATUS_CODES,
        db_index = True,
        verbose_name = _("Status"),
    )
    ## ForeignKey
    organization = models.ForeignKey (
        Organization,
        null = True, blank = True,
        related_name = "projects",
        db_index = True,
        verbose_name = _("Organization")
    )
    ## Campi
    name = models.CharField (
        max_length = 200,
        db_index = True,
        verbose_name = _("Project"),
    )
    description = models.TextField (
        null = True, blank = True,
        verbose_name = _("Description"),
    )
    date_start = models.DateField (
        db_index = True,
        verbose_name = _("Start Date"),
    )
    date_end = models.DateField (
        null = True, blank = True,
        db_index = True,
        verbose_name =  _("End Date"),
    )

    class Meta:
        verbose_name = _("Project")
        verbose_name_plural = _("Projects")
        permissions = (
            ("can_view_projects"   , "Can view projects"),
            ("list_all_projects"   , "Can list all projects"),
        )
        ordering = ['name']

    def __unicode__(self):
        return unicode(self.name)
