# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from organization.models import Contact

#######################################
# COURSE                              #
#######################################
class Course(DateModel, UserModel, OrderedModel, StatusModel):
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _('Name'),
    )

    class Meta:
        verbose_name = _("Course")
        verbose_name_plural = _("Courses")

    def __unicode__(self):
        return u"%s" % self.name

#######################################
# SECTION                             #
#######################################
class Section(DateModel, UserModel, OrderedModel, StatusModel):
    ## Campi Modello
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _('Name'),
    )

    class Meta:
        verbose_name = _("Section")
        verbose_name_plural = _("Sections")

    def __unicode__(self):
        return u"%s" % self.name

#######################################
# CLASSE                              #
#######################################
class ClassRoom(DateModel, UserModel, OrderedModel, StatusModel):
    ## ForeignKey
    course = models.ForeignKey(
        Course,
        db_index = True,
    )
    section = models.ForeignKey(
        Section,
        db_index = True,
    )
    year = models.IntegerField(
        db_index = True,
        verbose_name = _('Year'),
    )
    class Meta:
        verbose_name = _("Classroom")
        verbose_name_plural = _("Classrooms")

    def __unicode__(self):
        return u"%s: %s %s" % (self.year, self.course.name, self.section.name)

#######################################
# MEMBRI                              #
#######################################
ROLE = (
    ('T', _('Teacher')),
    ('S', _('Student')),
    ('P', _('Participant')),
)

class Member(DateModel, UserModel, OrderedModel, StatusModel):
    ## ForeignKey
    classroom = models.ForeignKey(
        ClassRoom,
        db_index = True,
        related_name = 'members',
        verbose_name = _('Class Room'),
    )
    member = models.ForeignKey(
        Contact,
        db_index = True,
        related_name = 'classrooms',
        verbose_name = _('Member'),
    )
    ## Campi Modello
    role = models.CharField(
        max_length = 1,
        choices = ROLE,
        db_index = True,
        verbose_name = _('Role'),
    )

    class Meta:
        verbose_name = _("Member")
        verbose_name_plural = _("Members")

    def __unicode__(self):
        return u"%s: %s %s" % (self.classroom.year, self.classroom.course.name, self.classroom.section.name)
