from django.db import models
from django.contrib.admin import widgets as admin_widgets
from django.utils.translation import ugettext_lazy as _

from jumbo.db import widgets

class HTMLField(models.TextField):
    """
    A large string field for HTML content. It uses the FCKeditor widget in
    forms.
    """
    def formfield(self, **kwargs):
        defaults = {'widget': widgets.HTMLarea}
        defaults.update(kwargs)

        # As an ugly hack, we override the admin widget
        if defaults['widget'] == admin_widgets.AdminTextareaWidget:
            defaults['widget'] = widgets.HTMLarea

        return super(HTMLField, self).formfield(**defaults)

STATUS_CODES = (
    (0, _('Inactive')),
    (1, _('Active')),
)

class StatusField(models.IntegerField):
    def __init__(self, choices=STATUS_CODES, max_length=3,
                 default='1', verbose_name=_('Status'), help_text=_('status help text')):
        super(StatusField, self).__init__(choices=choices, max_length=max_length, default=default, verbose_name=verbose_name, help_text=help_text)

