import re

from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponseRedirect
from django.core.urlresolvers import reverse

class AdminModelForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super(AdminModelForm, self).__init__(*args, **kwargs)
        try:
            self.fields['date_create'].required = False
            self.fields['date_last_modify'].required = False
        except:
            pass
        try:
            self.fields['creator'].required = False
            self.fields['last_modifier'].required = False
        except:
            pass
        try:
            self.fields['ordering'].required = False
        except:
            pass

class OrderedModelAdmin(admin.ModelAdmin):
    def get_urls(self):
        from django.conf.urls.defaults import patterns, url

        info = self.admin_site.name, self.model._meta.app_label, self.model._meta.module_name

        return patterns('',
            url(r'^(?P<id>\d+)/up/$', self.admin_site.admin_view(self.up), name='%sadmin_%s_%s_up' % info),
            url(r'^(?P<id>\d+)/down/$', self.admin_site.admin_view(self.down), name='%sadmin_%s_%s_down' % info),
        ) + super(OrderedModelAdmin, self).get_urls()

    def up(self, request, id):
        node = self.model._default_manager.get(pk=id)
        node.up()
        try:
            redirect_to = request.META['HTTP_REFERER']
        except:
            redirect_to = '../../'
        return HttpResponseRedirect(redirect_to)

    def down(self, request, id):
        node = self.model._default_manager.get(pk=id)
        node.down()
        try:
            redirect_to = request.META['HTTP_REFERER']
        except:
            redirect_to = '../../'
        return HttpResponseRedirect(redirect_to)

    def move_actions(self, node):
        info = self.admin_site.name, self.model._meta.app_label, self.model._meta.module_name
        args = [node.id]
        data = []
        if not node.is_first(): # up node
            data.append(u'<a href="%s" class="nodes-up">%s</a>' % (reverse('%sadmin_%s_%s_up' % info, args=args), _('up')))
        if not node.is_last() and not node.is_first():
            data.append(u'<span style="font-weight:normal"> | </span>')
        if not node.is_last(): # down node
            data.append(u'<a href="%s" class="nodes-down">%s</a>' % (reverse('%sadmin_%s_%s_down' % info, args=args), _('down')))
        return u''.join(data)
    move_actions.short_description = _('move')
    move_actions.allow_tags = True
