from django import forms
from django.utils.text import capfirst
from django.utils.translation import ugettext as _
from jumbo.forms.widgets import DateWidget, DateTimeWidget
from jumbo.middleware.thread_local import get_request

class ModelForm(forms.ModelForm):
    def __init__(self, *args, **kws):
        super(ModelForm, self).__init__(*args, **kws)
        if self.fields.has_key('date_create'):
            self.fields.pop('date_create')
            
        if self.fields.has_key('date_last_modify'):
            self.fields.pop('date_last_modify')
        self.overrideDateWidget()


    def overrideDateWidget(self, initial=None):
        opts = {'initial' : initial}
        for field in self.fields:
            if isinstance(self.fields[field], forms.DateTimeField):
                self.fields[field].widget = DateTimeWidget()
                
            elif isinstance(self.fields[field], forms.DateField):
                self.fields[field].widget = DateWidget()

    def save(self, commit=True, show_message=True, *arg, **kwargs):
        if self.instance.pk is None:
            action = _('created')
        else:
            action = _('changed')

        instance = super(ModelForm, self).save(commit=True, *arg, **kwargs)
        try:
            model_name = capfirst(self.instance._meta.verbose_name)
            request = get_request()

            if show_message:
                request.user.message_set.create(message=_("""The %(model_name)s "%(object_name)s" was %(action)s successfully""" % {
                                                                'object_name':unicode(instance),
                                                                'action': action,
                                                                'model_name': unicode(model_name)}))
        except:
            pass

        return instance


class ModelSearchForm(forms.ModelForm):
    def __init__(self, *args, **kw):
        try:
            initial_fields = self.Meta.initial_fields
        except AttributeError:
            initial_fields = {}

        try:
            meta_fields = self.Meta.fields
        except AttributeError:
            meta_fields = ()

        request = get_request()

        if not request.GET:
            initial_values = {}
            for field in meta_fields:
                initial_values[field] = initial_fields.get(field, None)
            kw.update({'initial': initial_values})

        super(ModelSearchForm, self).__init__(*args, **kw)

        for field in self.fields:
            self.fields[field].required = False

    def clean(self):
        return self.cleaned_data

    def filter(self):
        filters = {}
        try:
            search_fields = self.Meta.search_fields
        except AttributeError:
            search_fields = {}

        if self.is_valid():
            for field in self.cleaned_data:
                # Il controllo viene fatto cosi, perche se si mette solo l'if 
                # su self.cleaned_data[field] i valori delle select che hanno come
                # value 0 non verrebbero aggiunti nei filtri. Ad esempio la select
                # read dell'applicazione fax.
                #
                if self.cleaned_data[field] == 0 or self.cleaned_data[field]:
                    if field in search_fields:
                        operator = search_fields[field]
                    else:
                        operator = 'icontains'
                    filters.update({'%s__%s' % (field, operator,): self.cleaned_data[field]})

        try:
            self.change_filter(filters)
        except AttributeError:
            pass
        
        return filters
