import datetime
import time

from django import forms
from django.forms import widgets
from django.conf import settings
from django.utils.encoding import force_unicode
from django.utils.safestring import mark_safe
from django.forms.util import flatatt
from django.utils.translation import ugettext as _
from django.utils.datastructures import MultiValueDict

# DATETIMEWIDGET
calbtn = u"""<img src="%sjumbo/img/icon_calendar.gif" alt="calendar" id="%s_btn" style="cursor: pointer; margin-left:6px;" title="Select date and time"
            onmouseover="this.style.background='#444444';" onmouseout="this.style.background=''" />
<script type="text/javascript">
    Calendar.setup({
        inputField     :    "%s",
        ifFormat       :    "%s",       
        button         :    "%s_btn",
        singleClick    :    true,
        showsTime      :    true
    });
</script>"""

class DateTimeWidget(widgets.TextInput):
    ## FIXME: should depend on US/European input format
    dformat = '%d/%m/%Y %H:%M'
    default_input_formats = forms.fields.DEFAULT_DATETIME_INPUT_FORMATS

    def render(self, name, value, attrs=None):
        if value is None:
            value = ''

        final_attrs = self.build_attrs(attrs, type=self.input_type, name=name)
        if value != '': 
            try:
                final_attrs['value'] = \
                                   force_unicode(value.strftime(self.dformat))
            except:
                final_attrs['value'] = \
                                   force_unicode(value)
        
        if not final_attrs.has_key('id'):
            final_attrs['id'] = u'%s_id' % (name)
        id = final_attrs['id']
        
        jsdformat = self.dformat #.replace('%', '%%')
        cal = calbtn % (settings.MEDIA_URL, id, id, jsdformat, id)
        
        d_value = ""
        if final_attrs.has_key('default'):
            d_value = final_attrs["default"]

        return mark_safe(u'<input%s value="%s"/>%s' % (forms.util.flatatt(final_attrs), d_value, cal))

    def value_from_datadict(self, data, files, name):

        empty_values = forms.fields.EMPTY_VALUES
        
        value = data.get(name, None)

        if value in empty_values:
            return None
        if isinstance(value, datetime.datetime):
            return value
        if isinstance(value, datetime.date):
            return datetime.datetime(value.year, value.month, value.day)
        for format in self.default_input_formats:
            try:
                return datetime.datetime(*time.strptime(value, format)[:6])
            except ValueError:
                return value

        return None

class DateWidget(DateTimeWidget):
    dformat = '%d/%m/%Y'
    default_input_formats = forms.fields.DEFAULT_DATE_INPUT_FORMATS

class HTMLarea(widgets.Widget):
    def __init__(self, attrs=None):
        if attrs is not None:
            self.attrs = attrs.copy()
        else:
            self.attrs = {}
        super(HTMLarea, self).__init__(attrs)

    def render(self, name, value, attrs=None):
        html = []
        if value is None:
            value = ''
        value = force_unicode(value)

        final_attrs = self.build_attrs(attrs, name=name)
        clean_id = final_attrs['id'].replace('-', '')
        html.append(u"""<textarea %(attrs)s>%(value)s</textarea>
            <input type="button" name="_preview" onclick='preview%(cleanid)s();' value="Preview" />
        """)
        html.append(u"""<script>
        function preview%(cleanid)s()
        {
            var oEditor = FCKeditorAPI.GetInstance('%(name)s');
            document.getElementById('text_preview').value = oEditor.GetHTML();
            document.form_preview.submit();
        }
        </script>""")
        html.append(u'<script type="text/javascript">new FCKeditor(\'%(name)s\', \'100%%\', \'500\').ReplaceTextarea();</script>')
        return mark_safe(u''.join(html) % {'attrs': flatatt(final_attrs), 'id': final_attrs['id'], 'name': name,
                                           'value': value, 'msg': _('Add/Remove editor'),
                                           'cleanid': clean_id})

    def _media(self):
        return forms.Media(js=('%sfckeditor/fckeditor.js' % settings.MEDIA_URL,))
    media = property(_media)


class MultiFileInput(widgets.FileInput):
    """
    A widget to be used by the MultiFileField to allow the user to upload
    multiple files at one time.
    """
    
    def __init__(self, attrs=None):
        """
        Create a MultiFileInput.
        The 'count' attribute can be specified to default the number of 
        file boxes initially presented.
        """
        super(MultiFileInput, self).__init__(attrs)
        self.attrs = {'count':1}
        if attrs:
            self.attrs.update(attrs)
        
    def render(self, name, value, attrs=None):
        """
        Renders the MultiFileInput.
        Should not be overridden.  Instead, subclasses should override the
        js, link, and/or fields methods which provide content to this method.
        """
        final_attrs = self.build_attrs(attrs, type=self.input_type, name=name+'[]')
        count = final_attrs['count']
        if count<1: count=1
        del final_attrs['count']

        js = self.js(name, value, count, final_attrs)
        link = self.link(name, value, count, final_attrs)
        fields = self.fields(name, value, count, final_attrs) 

        return js+fields+link
    
    def fields(self, name, value, count, attrs=None):
        """
        Renders the necessary number of file input boxes.
        """
        return u''.join([u'<input%s />\n' % flatatt(dict(attrs, id=attrs['id']+str(i))) for i in range(count)])
        
    def link(self, name, value, count, attrs=None):
        """
        Renders a link to add more file input boxes.
        """
        return u"<a onclick=\"javascript:new_%(name)s()\">+</a>" % {'name':name}
        
    def js(self, name, value, count, attrs=None):
        """
        Renders a bit of Javascript to add more file input boxes.
        """
        return u"""
        <script>
        <!--
        %(id)s_counter=%(count)d;
        function new_%(name)s() {
            b=document.getElementById('%(id)s0');
            c=b.cloneNode(false);
            c.id='%(id)s'+(%(id)s_counter++);
            b.parentNode.insertBefore(c,b.parentNode.lastChild.nextSibling);
        }
        -->
        </script>
        """ % {'id':attrs['id'], 'name':name, 'count':count}

    def value_from_datadict(self, data, files, name):
        """
        File widgets take data from FILES, not POST.
        """
        name = name+'[]'
        if isinstance(files, MultiValueDict):
            return files.getlist(name)
        else:
            return None

    def id_for_label(self, id_):
        """
        The first file input box always has a 0 appended to it's id.
        """
        if id_:
            id_ += '0'
        return id_
    id_for_label = classmethod(id_for_label)

