from django.http import HttpResponse, HttpResponseForbidden
from django.utils.translation import ugettext as _
from jumbo.shortcuts import render_to_string

class HttpMessage(HttpResponse):
    status_code = 200

    def __init__(self, request, message, redirect_to, message_redirect=None, timeout=None, template_name='jumbo/message.html', attrs=None):
        if not attrs:
            attrs = {}
        if 'class' not in attrs:
            attrs.update({'class':'forbidden'})

        if not message_redirect:
            if timeout:
                message_redirect = _('You will be automatically redirect in %(seconds)s second') % {'seconds': timeout}
            else:
                message_redirect = _('Continue')
        
        text = render_to_string(
            template_name,
            request=request,
            message=message,
            redirect_to=redirect_to,
            message_redirect=message_redirect,
            timeout=timeout,
            **attrs
        )
        super(HttpMessage, self).__init__(text)

class HttpWarning(HttpMessage):
    status_code = 501

    def __init__(self, request, message, redirect_to, message_redirect=None, timeout=None, template_name='jumbo/message.html', attrs=None):
        if not attrs:
            attrs = {}
        if 'class' not in attrs:
            attrs.update({'class':'forbidden'})

        if not message_redirect:
            if timeout:
                message_redirect = _('You will be automatically redirect in %(seconds)s second') % {'seconds': timeout}
            else:
                message_redirect = _('Turn Back')

        super(HttpWarnig, self).__init__(
            request,
            message=message,
            redirect_to=redirect_to,
            message_redirect=message_redirect,
            timeout=timeout,
            template_name=template_name,
            attrs=attrs,
        )

class HttpError(HttpMessage):
    status_code = 501

    def __init__(self, request, message, redirect_to, message_redirect=None, timeout=None, template_name='jumbo/message.html', attrs=None):
        if not attrs:
            attrs = {}
        if 'class' not in attrs:
            attrs.update({'class':'forbidden'})

        if not message_redirect:
            if timeout:
                message_redirect = _('You will be automatically redirect in %(seconds)s second') % {'seconds': timeout}
            else:
                message_redirect = _('Turn Back')

        super(HttpError, self).__init__(
            request,
            message=message,
            redirect_to=redirect_to,
            message_redirect=message_redirect,
            timeout=timeout,
            template_name=template_name,
            attrs=attrs,
        )

class HttpForbidden(HttpResponseForbidden):
    def __init__(self, content=None):
        if not content:
            content = render_to_string('jumbo/forbidden.html')
        super(HttpForbidden, self).__init__(content)


