"""this middleware akes the user from a request and places it into a
threadlocal, so it can be retrieved in other contests

Stolen from a mail to django usergroup by Luke Plant - 17.6.2006
"""
#### myproject/middleware/threadlocals.py

try:
    from threading import local
except ImportError:
    # Python 2.3 compatibility
    from django.utils._threading_local import local

_thread_locals = local()

def get_current_user():
    from django.contrib.auth.models import User

    user = getattr(_thread_locals, 'user',  None)
    if user:
        return user
    else:
        from django.conf import settings
        try:
            u = getattr(settings, 'INTERACTIVE_USER', '')
            return User.objects.get(username=u)
        except User.DoesNotExist:
            return None

def get_request():
    request = getattr(_thread_locals, 'request', None)
    return request

class ThreadLocals(object):
    """Middleware that gets various objects from the
    request object and saves them in thread local storage."""
    def process_request(self, request):
        _thread_locals.request = request
        _thread_locals.user = getattr(request, 'user', None)

