from django.conf import settings
from django.contrib.admin.views.main import ALL_VAR, EMPTY_CHANGELIST_VALUE
from django.contrib.admin.views.main import ORDER_VAR, ORDER_TYPE_VAR, PAGE_VAR, SEARCH_VAR
from django.core.exceptions import ObjectDoesNotExist
from django.db import models
from django.utils import dateformat
from django.utils.html import escape, conditional_escape
from django.utils.text import capfirst
from django.utils.safestring import mark_safe
from django.utils.translation import get_date_formats, get_partial_date_formats, ugettext as _
from django.utils.encoding import smart_unicode, smart_str, force_unicode
from django.template import Library
import datetime

register = Library()

def result_headers(context, cl):
    lookup_opts = cl.model._meta

    request_get = context['request'].GET.copy()

    if hasattr(cl, 'default_order_by'):
        sort = request_get.get('sort', cl.default_order_by)
    else:
        sort = request_get.get('sort', None)

    is_desc = False
    if sort[0:1] == '-':
        is_desc = True

    if request_get.has_key('sort'):
        del request_get['sort']

    for i, field_name in enumerate(cl.list_display):
        attr = None
        try:
            f = lookup_opts.get_field(field_name)
            admin_order_field = None
        except models.FieldDoesNotExist:
            # For non-field list_display values, check for the function
            # attribute "short_description". If that doesn't exist, fall back
            # to the method name. And __str__ and __unicode__ are special-cases.
            if field_name == '__unicode__':
                header = force_unicode(lookup_opts.verbose_name)
            elif field_name == '__str__':
                header = smart_str(lookup_opts.verbose_name)
            else:
                if callable(field_name):
                    attr = field_name # field_name can be a callable
                else:
                    try:
                        attr = getattr(cl, field_name)
                    except AttributeError:
                        try:
                            attr = getattr(cl.model, field_name)
                        except AttributeError:
                            # Se non lo trovo come campo visualizzo direttamente il nome
                            # che trovo nella lista
                            pass

                try:
                    header = attr.short_description
                except AttributeError:
                    if callable(field_name):
                        header = field_name.__name__
                    else:
                        header = field_name
                    header = header.replace('_', ' ')

            # It is a non-field, but perhaps one that is sortable
            #order_field = getattr(attr, "sort_field", None)
            #if not order_field:
            #    yield {"text": header}
            #    continue

            # So this _is_ a sortable non-field.  Go to the yield
            # after the else clause.
        else:
            header = f.verbose_name

        if i == 0:
            th_classes = ['first']
        else:
            th_classes = []

        #new_order_type = 'asc'
        sortable = False

        if hasattr(cl, 'sort_field') and field_name in cl.sort_field.keys():
            sortable = True

        #    th_classes.append('sorted %sending' % cl.order_type.lower())
        #    new_order_type = {'asc': 'desc', 'desc': 'asc'}[cl.order_type.lower()]

        yield {"text": header,
               "sortable": sortable,
               "url": get_query_string(request_get, cl, field_name, is_desc),
               "class_attrib": mark_safe(th_classes and ' class="%s"' % ' '.join(th_classes) or '')}

def get_query_string(request_get, cl, field_name, is_desc):
    if not hasattr(cl, 'sort_field'):
        return ""
    sort_field = cl.sort_field
    k = sort_field.keys()
    if field_name in k:
        if is_desc:
            sort = sort_field[field_name]
        else:
            sort = "-%s" % sort_field[field_name]
        request_get['sort'] = sort
        return "?%s" % (request_get.urlencode(),)
    return ""


def items_for_result(form, result):
    first = True
    pk = form.model._meta.pk.attname
    for field_name in form.list_display:
        row_class = ''
        try:
            f = form.model._meta.get_field(field_name)
        except models.FieldDoesNotExist:
            # For non-field list_display values, the value is either a method,
            # property or returned via a callable.
            try:
                if hasattr(form, field_name):
                    attr = getattr(form, field_name)
                    if callable(attr):
                        value = attr(result)
                    else:
                        value = attr
                elif callable(field_name):
                    attr = field_name
                    value = attr(result)
                elif hasattr(form.model, field_name) and \
                   not field_name == '__str__' and not field_name == '__unicode__':
                    attr = getattr(form.model, field_name)
                    value = attr(result)
                else:
                    attr = getattr(result, field_name)
                    if callable(attr):
                        value = attr()
                    else:
                        value = attr
                allow_tags = getattr(attr, 'allow_tags', False)
                boolean = getattr(attr, 'boolean', False)
                if boolean:
                    allow_tags = True
                    result_repr = _boolean_icon(value)
                else:
                    result_repr = smart_unicode(value)
            except (AttributeError, ObjectDoesNotExist):
                result_repr = EMPTY_CHANGELIST_VALUE
            else:
                # Strip HTML tags in the resulting text, except if the
                # function has an "allow_tags" attribute set to True.
                #if not allow_tags:
                #    result_repr = escape(result_repr)
                #else:
                result_repr = mark_safe(result_repr)
        else:
            field_val = getattr(result, f.attname)

            if isinstance(f.rel, models.ManyToOneRel):
                if field_val is not None:
                    result_repr = escape(getattr(result, f.name))
                else:
                    #result_repr = EMPTY_CHANGELIST_VALUE
                    result_repr = ''
            # Dates and times are special: They're formatted in a certain way.
            elif isinstance(f, models.DateField) or isinstance(f, models.TimeField):
                if field_val:
                    (date_format, datetime_format, time_format) = get_date_formats()
                    if isinstance(f, models.DateTimeField):
                        result_repr = capfirst(dateformat.format(field_val, datetime_format))
                    elif isinstance(f, models.TimeField):
                        result_repr = capfirst(dateformat.time_format(field_val, time_format))
                    else:
                        result_repr = capfirst(dateformat.format(field_val, date_format))
                else:
                    result_repr = EMPTY_CHANGELIST_VALUE
                row_class = ' class="nowrap"'
            # Booleans are special: We use images.
            elif isinstance(f, models.BooleanField) or isinstance(f, models.NullBooleanField):
                result_repr = _boolean_icon(field_val)
            # DecimalFields are special: Zero-pad the decimals.
            elif isinstance(f, models.DecimalField):
                if field_val is not None:
                    result_repr = ('%%.%sf' % f.decimal_places) % field_val
                else:
                    result_repr = EMPTY_CHANGELIST_VALUE
            # Fields with choices are special: Use the representation
            # of the choice.
            elif f.choices:
                result_repr = dict(f.choices).get(field_val, EMPTY_CHANGELIST_VALUE)
            else:
                #result_repr = escape(field_val)
                if field_val:
                    result_repr = escape(field_val)
                else:
                    result_repr = ''

        if force_unicode(result_repr) == '':
            result_repr = mark_safe('&nbsp;')
        # If list_display_links not defined, add the link tag to the first field
        #if (first and not cl.list_display_links) or field_name in cl.list_display_links:
        #    table_tag = {True:'th', False:'td'}[first]
        #    first = False
        #    url = cl.url_for_result(result)
        #    # Convert the pk to something that can be used in Javascript.
        #    # Problem cases are long ints (23L) and non-ASCII strings.
        #    if cl.to_field:
        #        attr = str(cl.to_field)
        #    else:
        #        attr = pk
        #    value = result.serializable_value(attr)
        #    result_id = repr(force_unicode(value))[1:]
        #    yield mark_safe(u'<%s%s><a href="%s"%s>%s</a></%s>' % \
        #        (table_tag, row_class, url, (cl.is_popup and ' onclick="opener.dismissRelatedLookupPopup(window, %s); return false;"' % result_id or ''), conditional_escape(result_repr), table_tag))
        #else:
        # By default the fields come from ModelAdmin.list_editable, but if we pull
        # the fields out of the form instead of list_editable custom admins
        # can provide fields on a per request basis
        #if form and field_name in form.fields:
        #    bf = form[field_name]
        #    result_repr = mark_safe(force_unicode(bf.errors) + force_unicode(bf))
        #else:
        result_repr = conditional_escape(result_repr)
        yield mark_safe(u'<td%s>%s</td>' % (row_class, result_repr))

def _boolean_icon(field_val):
    BOOLEAN_MAPPING = {True: 'yes', False: 'no', None: 'unknown'}
    return mark_safe(u'<img src="%simg/admin/icon-%s.gif" alt="%s" />' % (settings.ADMIN_MEDIA_PREFIX, BOOLEAN_MAPPING[field_val], field_val))

def results(form, qs):
    for res in qs:
        yield list(items_for_result(form, res))

@register.inclusion_tag("jumbo/tags/change_list.html", takes_context=True)
def result_list(context, form, qs):
    if hasattr(form, 'object_name'):
        context['object_name'] = form.object_name
    else:
        context['object_name'] = _("List %(model)s") % {'model':form.model._meta.object_name}
    context['form'] = form
    context['result_headers'] = list(result_headers(context, form))
    context['results'] = list(results(form, qs))
    return context
