from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from django.db import models
from django.utils.translation import get_date_formats, get_partial_date_formats, ugettext as _
from django.utils.encoding import smart_unicode, smart_str, force_unicode
from django.template import Library
import datetime

register = Library()

def result_headers(context, cl):
    lookup_opts = cl.model._meta

    request_get = context['request'].GET.copy()

    if hasattr(cl, 'default_order_by'):
        sort = request_get.get('sort', cl.default_order_by)
    else:
        sort = request_get.get('sort', None)

    is_desc = False
    if sort[0:1] == '-':
        is_desc = True

    if request_get.has_key('sort'):
        del request_get['sort']

    for i, field_name in enumerate(cl.list_display):
        attr = None
        try:
            f = lookup_opts.get_field(field_name)
            admin_order_field = None
        except models.FieldDoesNotExist:
            # For non-field list_display values, check for the function
            # attribute "short_description". If that doesn't exist, fall back
            # to the method name. And __str__ and __unicode__ are special-cases.
            if field_name == '__unicode__':
                header = force_unicode(lookup_opts.verbose_name)
            elif field_name == '__str__':
                header = smart_str(lookup_opts.verbose_name)
            else:
                if callable(field_name):
                    attr = field_name # field_name can be a callable
                else:
                    try:
                        attr = getattr(cl, field_name)
                    except AttributeError:
                        try:
                            attr = getattr(cl.model, field_name)
                        except AttributeError:
                            # Se non lo trovo come campo visualizzo direttamente il nome
                            # che trovo nella lista
                            pass

                try:
                    header = attr.short_description
                except AttributeError:
                    if callable(field_name):
                        header = field_name.__name__
                    else:
                        header = field_name
                    header = header.replace('_', ' ')

            # It is a non-field, but perhaps one that is sortable
            #order_field = getattr(attr, "sort_field", None)
            #if not order_field:
            #    yield {"text": header}
            #    continue

            # So this _is_ a sortable non-field.  Go to the yield
            # after the else clause.
        else:
            header = f.verbose_name

        th_classes = []
        #new_order_type = 'asc'
        sortable = False

        if hasattr(cl, 'sort_field') and field_name in cl.sort_field.keys():
            sortable = True

        #    th_classes.append('sorted %sending' % cl.order_type.lower())
        #    new_order_type = {'asc': 'desc', 'desc': 'asc'}[cl.order_type.lower()]

        yield {"text": header,
               "sortable": sortable,
               "url": get_query_string(request_get, cl, field_name, is_desc),
               "class_attrib": mark_safe(th_classes and ' class="%s"' % ' '.join(th_classes) or '')}


@register.inclusion_tag("jumbo/tags/search_form.html", takes_context=True)
def search_form(context, search_form):
    context['search_form'] = search_form
    context['tr_fields'] = search_form.Meta.list_fields
    #context['results'] = list(results(form, qs))
    return context

@register.simple_tag
def render_label(search_form, field):
    f = search_form.fields.get(field, None)
    return f.label

@register.simple_tag
def render_field(search_form, field):
    f = search_form.fields.get(field, None)
    return f.widget.render()
