def render_csv(rows, filename=None):
    from django.http import HttpResponse
    response = HttpResponse(mimetype='text/csv')
    if not filename:
        filename = 'file.csv'
    response['Content-Disposition'] = 'attachment; filename= %s' % filename
    response.write(rows)
    return response

def set_default_date_input_european():
    from django.forms import fields, widgets

    DATE_INPUT_FORMATS = (
        '%Y-%m-%d', '%Y/%m/%d',             # '2008-10-25', '2008/10/25'
        '%d-%m-%Y', '%d/%m/%Y',             # '25-10-2006', '25/10/2006'
        '%d-%m-%y', '%d/%m/%y',             # '25-10-06', '25/10/06'
    )
    DATETIME_INPUT_FORMATS = (
        '%Y-%m-%d %H:%M:%S',     # '2006-10-25 14:30:59'
        '%Y-%m-%d %H:%M',        # '2006-10-25 14:30'
        '%Y-%m-%d',              # '2006-10-25'
        '%d/%m/%Y %H:%M:%S',     # '10/25/2006 14:30:59'
        '%d/%m/%Y %H:%M',        # '10/25/2006 14:30'
        '%d/%m/%Y',              # '10/25/2006'
        '%d/%m/%y %H:%M:%S',     # '10/25/06 14:30:59'
        '%d/%m/%y %H:%M',        # '10/25/06 14:30'
        '%d/%m/%y',              # '10/25/06'
    )

    setattr(fields, 'DEFAULT_DATE_INPUT_FORMATS', DATE_INPUT_FORMATS)
    setattr(fields, 'DEFAULT_DATETIME_INPUT_FORMATS', DATETIME_INPUT_FORMATS)
    setattr(widgets.DateTimeInput, 'format', '%d/%m/%Y %H:%M:%S')

def zerofill(x, width=6):
    return "%0*d" % (width, x)

def get_formatted_time(ms, seconds=True):
    if not ms:
        return ''
    ftime= ""
    if seconds:
        ftime= "0s"
    s=ms/1000
    m,s=divmod(s,60)
    h,m=divmod(m,60)
    d,h=divmod(h,24)
    if seconds and s > 0:
        ftime = "%ss" % s
    if m > 0:
        ftime = "%sm %s" % (m, ftime)
    if h > 0:
        ftime = "%sh %s" % (h, ftime)
    if d > 0:
        ftime = "%sg %s" % (d, ftime)

    return ftime

def get_random_string(self, length=10):
    import random, string
    return ''.join(random.sample(string.digits+string.letters, length))

def get_settings(model, val):
    from django.conf import settings
    from django.db.models.loading import get_model, get_app
    from django.utils.importlib import import_module

    use_db_settings = getattr(settings, "USE_DB_SETTINGS", True)
    value_settings = None

    full_app_name = None
    app_label = None
    model_name = None

    m = model.split(".")
    try:
        full_app_name = '.'.join(m[0:-1])
        app_label = m[-2]
        model_name = m[-1]
    except:
        pass

    try:
        model = get_model(app_label, model_name)
    except:
        model = None

    # CERCO LA PROPRIETA' PRIMA NEL DB
    if use_db_settings:
        if model:
            try:
                dbsettings = model.objects.get(name=val)
                value_settings = get_correct_type_settings(dbsettings)
            except:
                value_settings = None

    # SE NON LA TROVO LA VADO A CERCARE NEI SETTINGS DELL'APPLICAZIONE
    # PRIMA CERCO SE IL FILE DEI SETTTINGS DELL'APPLICAZIONE ESISTE
    if full_app_name and value_settings is None:
        try:
            app_settings = import_module('.settings', full_app_name)
            value_settings = getattr(app_settings, val, None)
        except Exception, e:
            value_settings = None

    # SE NON LA TROVO LA VADO A CERCARE NEI SETTINGS GENERALI
    if value_settings is None:
        value_settings = getattr(settings, val, None)

    # SE NON LA TROVO NEANCHE QUA GENERO UN'ECCEZIONE
    if value_settings is None:
        raise Exception("The properties %s does not exists." % val)

    return value_settings

def get_correct_type_settings(dbsettings):
    if dbsettings.type == "BOOLEAN":
        if dbsettings.value in ('1', 'True'):
            return True
        else:
            return False

    if dbsettings.type == "INTEGER":
        if dbsettings.value.isdigit():
            return int(dbsettings.value)
        else:
            return None

    if dbsettings.type == "LIST":
        v = dbsettings.value.split(',')
        return [ x.strip() for x in v ]

    if dbsettings.type == "STRING":
        return str(dbsettings.value)

def get_groups_w_perm(perm_app, perm_model, perm_name):
    ## restituisce i gruppi che hanno il permesso passato #
    from django.contrib.auth.models import User, Group, Permission
    from jumbo.middleware.thread_local import get_current_user
    user = get_current_user()
    if user.is_staff:
        valid_groups = Group.objects.all()
    elif not user.is_active:
        valid_groups = Group.objects.none()
    else:
        valid_groups = Group.objects.filter(user__id = user.id).filter(permissions__codename = perm_name).filter(permissions__content_type__app_label = perm_app).filter(permissions__content_type__model = perm_model).distinct()
    return valid_groups