from django.utils import simplejson
from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.views.generic.create_update import lookup_object
from django.contrib.admin.util import get_deleted_objects
from django.utils.encoding import force_unicode
from django.utils.text import capfirst
from django.utils.html import escape
from django.utils.safestring import mark_safe
from django.db.models.query import CollectedObjects
from django.utils.translation import ugettext as _

from jumbo.middleware.thread_local import get_request, get_current_user
from jumbo.shortcuts import render_to_response, render_to_string

def delete_object(model, object_id):
    app_label = model._meta.app_label
    request = get_request()
    response = "ERROR"

    if request.user.has_perm('%s.%s' % (model._meta.app_label,
                                        model._meta.get_delete_permission())
                            ):
        t = model.objects.get(pk=object_id)
        t.delete()
        response = "OK"
    else:
        response = "ATTENZIONE!! Non hai i permessi per eseguire questa operazione"

    return response


def generic_delete_object(request, model, post_delete_redirect=None, object_id=None,
        slug=None, slug_field='slug', template_name=None,
        extra_context=None, login_required=True,
        context_processors=None, template_object_name='object'):

    if not request.user.has_perm('%s.%s' % (model._meta.app_label,
                                        model._meta.get_delete_permission())
                            ):
        return HttpResponseForbidden(render_to_string('jumbo/generic_error.html', 
                                                      is_popup=True,
                                                      error=_("You don't have permissions to delete the object.")))

    if extra_context is None: extra_context = {}
    if login_required and not request.user.is_authenticated():
        return redirect_to_login(request.path)

    opts = model._meta
    obj = lookup_object(model, object_id, slug, slug_field)

    if request.method == 'POST':
        obj.delete()

        if request.user.is_authenticated():
            request.user.message_set.create(message=mark_safe(_("The %(verbose_name)s %(object_name)s was deleted.") % {"verbose_name": opts.verbose_name,
                                                                                                              "object_name": unicode(obj)}))
        if request.POST.has_key("_popup"):
            return HttpResponse("""<script type="text/javascript">
                                        window.opener.location.reload();
                                        window.close();
                                </script>""")
        else:
            return HttpResponseRedirect(post_delete_redirect)
    else:
        if not template_name:
            template_name = "jumbo/generic_delete.html"

        # deletable_objects must be a list if we want to use '|unordered_list' in the template
        deletable_objects = []
        co = CollectedObjects()
        obj._collect_sub_objects(co)

        for model in co.ordered_keys():
            for d in co[model].iteritems():
                deletable_objects.append("%s -> %s" % (unicode(model._meta.object_name), unicode(d[1])))

        # tolgo l'ultimo elemento perche mi rappresenta sempre l'oggetto stesso
        deletable_objects.pop()
        return render_to_response(template_name, object_name=obj, deletable_objects=deletable_objects)


def get_query_set(search_class, search_form=None):
    user = get_current_user()
    request = get_request()
    get =  request.GET.copy()

    model_s = search_class()

    orderby = get.get('sort', model_s.default_order_by)
    direction = get.get('dir', 'asc')

    if hasattr(model_s, "get_query_set"):
        queryset = model_s.get_query_set(request)
    else:
        queryset = model_s.model.objects.all()

    if search_form:
        if hasattr(model_s, "change_filter"):
            sf = model_s.change_filter(search_form.filter())
        else:
            sf = search_form.filter()
        queryset = queryset.filter(**sf)

    # Se la classe ha un metodo order_by chiamo quello, altrimenti
    # lo gestisco direttamente io in base al campo passato dal javascript
    if hasattr(model_s, "order_by"):
        queryset = model_s.order_by(queryset, orderby, direction)
    else:
        if type(orderby) == type(()):
            queryset = queryset.order_by(*orderby)
        else:
            if direction == 'desc':
                orderby = "-%s" % orderby
            queryset = queryset.order_by(orderby)

    return queryset


def get_search_data(search_class, search_form, default_limit = 25):
    user = get_current_user()
    request = get_request()
    get =  request.GET.copy()

    model_s = search_class()

    start = get.get('start', 0)
    limit = get.get('limit', default_limit)
    groupby = get.get('groupBy', '')
    orderby = get.get('sort', model_s.default_order_by)
    direction = get.get('dir', 'ASC')

    if hasattr(model_s, "get_query_set"):
        queryset = model_s.get_query_set(request)
    else:
        queryset = model_s.model.objects.all()

    # Gestione della ricerca
    #
    search_form = search_form(request.GET)

    if hasattr(model_s, "change_filter"):
        sf = model_s.change_filter(search_form.filter())
    else:
        sf = search_form.filter()

    queryset = queryset.filter(**sf)

    total = queryset.count()

    # Se la classe ha un metodo order_by chiamo quello, altrimenti
    # lo gestisco direttamente io in base al campo passato dal javascript
    if hasattr(model_s, "order_by"):
        queryset = model_s.order_by(queryset, groupby, orderby, direction)
    else:
        if direction == 'DESC':
            orderby = "-%s" % orderby
        queryset = queryset.order_by(orderby)

    queryset = queryset[int(start):int(start)+int(limit)]

    data = model_s.get_data(queryset)

    data = '{"success": true, "total": %s, "data": %s}' % (total, simplejson.dumps(data, ensure_ascii=False))
    return data

def move_up(request, object_id, model):
    obj = lookup_object(model, object_id, None, 'slug')
    obj.up()
    try:
        redirect_to = request.META['HTTP_REFERER']
    except:
        redirect_to = '../../'
    return HttpResponseRedirect(redirect_to)

def move_down(request, object_id, model):
    obj = lookup_object(model, object_id, None, 'slug')
    print obj
    obj.down()
    try:
        redirect_to = request.META['HTTP_REFERER']
    except:
        redirect_to = '../../'
    return HttpResponseRedirect(redirect_to)
